@@ -5,14 +5,13 @@ from tsdoc0.python.segment import Segment
 from typing import Final
 from typing import Iterable
 from typing import Optional
-from typing import Tuple
 
 import attr
 
 
 # This converter wrapper-function is used because of a bug with the mypy-attrs plugin.
 # https://github.com/python/mypy/issues/8389
-def _tuple(iterable: Iterable[CommentSentence]) -> Tuple[CommentSentence, ...]:
+def _tuple(iterable: Iterable[CommentSentence]) -> tuple[CommentSentence, ...]:
     return tuple(iterable)
 
 
@@ -20,7 +19,7 @@ def _tuple(iterable: Iterable[CommentSentence]) -> Tuple[CommentSentence, ...]:
 class CommentAbstract(Segment):
     parent: Optional[Model] = attr.ib(eq=False, repr=repr_parent)
     indentation: Final[str]  # type: ignore[misc]
-    sentences: Final[Tuple[CommentSentence, ...]] = attr.ib(converter=_tuple)
+    sentences: Final[tuple[CommentSentence, ...]] = attr.ib(converter=_tuple)
 
     @property
     def answer(self) -> str:
